==> strigiapplet_0.3.11.orig.tar.gz: strigiapplet-0.3.11.orig/src/strigi/strigi.h <==
/* This file is part of Strigi Desktop Search
 *
 * Copyright (C) 2006 Jos van den Oever <jos@vandenoever.info>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */
#ifndef _strigi_H_
#define _strigi_H_

#include <qstring.h>
#include <qcstring.h>

#include <kurl.h>
#include <kio/global.h>
#include <kio/slavebase.h>
#include <kio/jobclasses.h>
#include <strigihtmlgui.h>

class QCString;
class KFileItem;

class kio_strigiProtocol : public QObject, public KIO::SlaveBase
{
Q_OBJECT
private:
    class Helper;
    Helper* helper;
    StrigiHtmlGui htmlgui;
    QByteArray icondata;
    int dataSent;

    void getIcon(const QString& file);
private slots:
    void slotData(KIO::Job *job, const QByteArray &data);
    void jobFinished( KIO::Job* job );
    void slotPreview (const KFileItem *item, const QPixmap &preview);
public:
    kio_strigiProtocol(const QCString &protocol, const QCString &pool_socket, const QCString &app_socket);
    virtual ~kio_strigiProtocol();
    virtual void mimetype(const KURL& url);
    virtual void get(const KURL& url);
    virtual void listDir ( const KURL& url );
};

#endif

==> strigiapplet_0.5.7.orig.tar.gz: strigiapplet-0.5.7/src/strigi/strigi.h <==
/* This file is part of Strigi Desktop Search
 *
 * Copyright (C) 2006 Jos van den Oever <jos@vandenoever.info>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */
#ifndef _strigi_H_
#define _strigi_H_

#include <qstring.h>
#include <qcstring.h>

#include <kurl.h>
#include <kio/global.h>
#include <kio/slavebase.h>
#include <kio/jobclasses.h>
#include <strigi/strigihtmlgui.h>

class QCString;
class KFileItem;

class kio_strigiProtocol : public QObject, public KIO::SlaveBase
{
Q_OBJECT
private:
    class Helper;
    Helper* helper;
    StrigiHtmlGui htmlgui;
    QByteArray icondata;
    int dataSent;

    void getIcon(const QString& file);
private slots:
    void slotData(KIO::Job *job, const QByteArray &data);
    void jobFinished( KIO::Job* job );
    void slotPreview (const KFileItem *item, const QPixmap &preview);
public:
    kio_strigiProtocol(const QCString &protocol, const QCString &pool_socket, const QCString &app_socket);
    virtual ~kio_strigiProtocol();
    virtual void mimetype(const KURL& url);
    virtual void get(const KURL& url);
    virtual void listDir ( const KURL& url );
};

#endif
